@@ -17,8 +17,14 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 /* PROGNAME will be used in error messages, etc. */
 #define	PROGNAME	"integrit"
 
-/* version string */
-#define	INTEGRIT_VERSION	"1.00"
+/* version string lives in configure.in */
+#undef	INTEGRIT_VERSION
+
+/* define this for debugging runtime diagnostics to stderr */
+#undef	DEBUG
+
+/* define this to compile in memory-leak detection */
+#undef	ELC_FIND_LEAKS
 
 /* Define this if your system provides strstr */
 #undef	HAVE_STRSTR
@@ -26,4 +32,6 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 /* Define this if your system provides strerror */
 #undef	HAVE_STRERROR
 
+/* (end acconfig.h) */
+
 @TOP@
