@@ -17,6 +17,7 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	<stdio.h>
 #include	<stdlib.h>
 #include	<string.h>
+#include	<limits.h>
 #include	<errno.h>
 #include	"checkset.h"
 #include	"elcerror.h"
@@ -26,6 +27,14 @@ MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 #include	"leakfind.h"
 #endif
 
+void checkset_init(checkset c, size_t n)
+{
+    if (n > CHECKSET_MAXLEN)
+      DIE("too many members for checkset");
+    c[0]	 = n;
+    c[1]	 = 0;
+}
+
 void checkset_show(FILE *out, checkset c)
 {
     int		i;
@@ -36,7 +45,7 @@ void checkset_show(FILE *out, checkset c)
       putc('=', out);
 
     for (i = 0; i < CHECKSET_LEN(c); ++i)
-      putc(CHECKSET_GET(c, i), out);
+      putc(CHECKSET_SWITCH_AT(c, i), out);
 }
 
 checkset checkset_new(size_t n)
