@@ -268,7 +268,8 @@ inline static void do_rule(options *o, char *buf)
     checkset_init(cset, n_switches);
     CHECKSET_SETIGNORE(cset, ignore);
     CHECKSET_SETNOCHILD(cset, nochildren);
-    strcpy(CHECKSET_SWITCHSTART(cset), buf);
+
+    memcpy(CHECKSET_SWITCHSTART(cset), buf, n_switches);
     
     chomp(namebuf);
 #ifdef	DEBUG
